==> php81-nextcloud-28.0.2.tgz: share/nextcloud/apps/theming/l10n/sr.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Назив је предугачак",
    "The given web address is too long" : "Наведена веб адреса је предугачка",
    "The given web address is not a valid URL" : "Наведена веб адреса није исправан УРЛ",
    "The given legal notice address is too long" : "Адреса правног обавештења је предугачка",
    "The given legal notice address is not a valid URL" : "Адреса правног обавештења није исправан УРЛ",
    "The given privacy policy address is too long" : "Адреса смерница приватности је предугачка",
    "The given privacy policy address is not a valid URL" : "Адреса смерница приватности није исправан УРЛ",
    "The given slogan is too long" : "Слоган је предугачак",
    "The given color is invalid" : "Задата боја није исправна",
    "Disable-user-theming should be true or false" : "Искључи-корисничке-теме би требало да буде true или false",
    "Saved" : "Сачувано",
    "Invalid app given" : "Наведена је неисправна апликација",
    "Invalid type for setting \"defaultApp\" given" : "Наведен је неисправан тип за постављање „defaultApp”",
    "Invalid setting key" : "Неисправан кључ подешавања",
    "The file was uploaded" : "Фајл је отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Отпремани фајл превазилази смерницу upload_max_filesize у фајлу php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE наведену у ХТМЛ обрасцу",
    "The file was only partially uploaded" : "Фајл је само делимично отпремљен",
    "No file was uploaded" : "Није отпремљен фајл",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Could not write file to disk" : "Не могу да упишем фајл на диск",
    "A PHP extension stopped the file upload" : "ПХП екстензија је зауставила отпремање фајла",
    "No file uploaded" : "Није отпремљен фајл",
    "Failed to clean up the old administration theming images folder" : "Није успело чишћење фолдера са старим сликама административне теме",
    "Failed to clean up the old administration image folder" : "Није успело чишћење фолдера са старим сликама администрације ",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Већ користите прилагођену тему. Поставке ове апликације ће прегажене са њом.",
    "Theming" : "Изглед",
    "Appearance and accessibility" : "Изглед и приступачност",
    "PHP Imagick module" : "PHP Imagick модул",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP модул „imagick” није укључен мада је укључена апликација за теме. Да би генерисање favicon сличице функционисало како треба, морате да инсталирате и укључите овај модул.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "PHP модул „imagick” у овој инстанци нема подршку за SVG. Да бисте постигли бољу компатибилност, препоручује се да га инсталирате.",
    "Dark theme with high contrast mode" : "Тамна тема са режимом високог контраста",
    "Enable dark high contrast mode" : "Укључи тамни режим високог контраста",
    "Similar to the high contrast mode, but with dark colours." : "Слично као режим високог контраста, али са тамним бојама.",
    "Dark theme" : "Тамна тема",
    "Enable dark theme" : "укључи тамну тему",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Тамна тема која не замара ваше очи тако што смањује општу сјајност и осветљеност.",
    "System default theme" : "Подразумевана системска тема",
    "Enable the system default" : "Укључи подразумевано за систем",
    "Using the default system appearance." : "Користи се подразумевани изглед система.",
    "Dyslexia font" : "Фонт Дислексија",
    "Enable dyslexia font" : "укључи фонт Дислексија",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "„OpenDyslexic“ је бесплатни фонт дизајниран да умањи честе грешке у читању изазване дислексијом.",
    "High contrast mode" : "Режим високог контраста",
    "Enable high contrast mode" : "укључи режим високог контраста",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Режим високог контраста за лакшу навигацију. Визуелни доживљај биће лошији али ће јасноћа бити боља.",
    "Light theme" : "Светла тема",
    "Enable the default light theme" : "Укључује подразумевану светлу тему",
    "The default light appearance." : "Подразумевани светли изглед.",
    "Legal notice" : "Правно обавештење",
    "Privacy policy" : "Смернице приватности",
    "Adjust the Nextcloud theme" : "Прилагоди Некстклауд тему",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Омогућава да лако измените изглед и угођај вашег Некстклауда. Ово ће бити видљиво свим корисницима.",
    "Advanced options" : "Напредне опције",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Инсталирајте ImageMagick PHP проширење са подшком за SVG слике да би било могуће аутоматско генерисање favicons према отпремљеном логоу и боји.",
    "Name" : "Назив",
    "Web link" : "Веб веза",
    "a safe home for all your data" : "сигурно место за све ваше податке",
    "Slogan" : "Слоган",
    "Color" : "Боја",
    "Logo" : "Лого",
    "Upload new logo" : "Отпремите нови лого",
    "Background and login image" : "Позадина и слика пријављивања",
    "Upload new background and login image" : "Отпреми нову слику позадине и пријављивања",
    "Legal notice link" : "Правно обавештење",
    "Privacy policy link" : "Смернице приватности",
    "Header logo" : "Лого заглавља",
    "Upload new header logo" : "Отпремите нови лого заглавља",
    "Favicon" : "Икона веб стране",
    "Upload new favicon" : "Отпремите нову иконицу",
    "User settings" : "Корисничка подешавања",
    "Disable user theming" : "Искључи корисничке теме",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Мада можете да изаберете и прилагодите своју инстанцу, корисници такође могу да промене своју позадину и боје. Ако желите да форсирате своје прилагођавање, укључите ово подешавање.",
    "Appearance and accessibility settings" : "Подешавања изгледа и приступачности",
    "Background" : "Позадина",
    "Customization has been disabled by your administrator" : "Администратор је искључио могућност прилагођавања",
    "Set a custom background" : "Постави пролагођену позадину",
    "Keyboard shortcuts" : "Пречице на тастатури",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "У неким случајевима пречице тастатуре могу да ремете алатке приступачности. Ако желите да се ваш алат исправно фокусира, овде можете да искључите све пречице на тастатури. Ово ће такође да искључи и све пречице у апликацијама.",
    "Disable all keyboard shortcuts" : "Искључи све пречице на тастатури",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Универзални приступ нам је веома важан. Пратимо веб стандарде и проверавамо да све буде употребљиво и без миша а и са помоћним софтвером попут читача екрана. Циљ нам је да будемо усклађени са документом {guidelines}Смернице приступачности веб садржаја{linkend}  2.1 на АА нивоу а са темом високог контраста и на ААА нивоу.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "У случају да наиђете на било какве проблеме, не оклевајте да их пријавите на {issuetracker}наш пратилац проблема{linkend}. А ако желите да се умешате, слободно се прикључите {designteam}нашем дизајн тиму{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Тренутно изабрана апликација: {app}, позиција {position} од {total}",
    "Move up" : "Помери нагоре",
    "Move down" : "Помери надоле",
    "Custom background" : "Прилагођена позадина",
    "Default background" : "Подразумевана позадина",
    "Change color" : "Промени боју",
    "No background" : "Без позадине",
    "Select a background from your files" : "Изаберите позадину међу вашим фајловима",
    "Select background" : "Изаберите позадину",
    "No background has been selected" : "Није изабрана ниједна позадина",
    "Theme selection is enforced" : "Избор теме је форсиран",
    "Navigation bar settings" : "Подешавања траке за навигацију",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Можете да подесите редослед апликација који ће се користити на траци за навигацију. Прва ставка ће бити подразумевана апликација која се отвара након пријаве или када се кликне на лого.",
    "The default app can not be changed because it was configured by the administrator." : "Подразумевана апликација не може да се промени јер ју је подесио администратор.",
    "The app order was changed, to see it in action you have to reload the page." : "Редослед апликација је променњен, да бисте видели како изгледа, поново учитајте страницу.",
    "Reset default app order" : "Ресетуј подразумевани редослед апликација.",
    "Could not set the app order" : "Није могао да се подеси редослед апликација",
    "Could not reset the app order" : "Није могао да се ресетује редослед апликација",
    "Default app" : "Подразумевана апликација",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Подразумевана апликација је она која се нпр. отвара након пријаве или када се кликне на лого у менију.",
    "Use custom default app" : "Користи произвољну подразумевану апликацију",
    "Global default app" : "Глобална подразумевана апликација",
    "Global default apps" : "Глобалне подразумеване апликације",
    "Default app priority" : "Подразумевани приоритет апликације",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Ако апликација није укључена за корисника, користиће се наредна апликација са нижим приоритетом.",
    "Could not set global default apps" : "Нису могле да се поставе глобалне подразумеване апликације",
    "Reset to default" : "Врати на подразумевано",
    "Upload" : "Отпреми",
    "Remove background image" : "Уклони позадинску слику",
    "Select a custom color" : "Изаберите прилагођену боју"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> php81-nextcloud-29.0.8.tgz: share/nextcloud/apps/theming/l10n/sr.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Назив је предугачак",
    "The given web address is too long" : "Наведена веб адреса је предугачка",
    "The given web address is not a valid URL" : "Наведена веб адреса није исправан УРЛ",
    "The given legal notice address is too long" : "Адреса правног обавештења је предугачка",
    "The given legal notice address is not a valid URL" : "Адреса правног обавештења није исправан УРЛ",
    "The given privacy policy address is too long" : "Адреса смерница приватности је предугачка",
    "The given privacy policy address is not a valid URL" : "Адреса смерница приватности није исправан УРЛ",
    "The given slogan is too long" : "Слоган је предугачак",
    "The given color is invalid" : "Задата боја није исправна",
    "Disable-user-theming should be true or false" : "Искључи-корисничке-теме би требало да буде true или false",
    "Saved" : "Сачувано",
    "Invalid app given" : "Наведена је неисправна апликација",
    "Invalid type for setting \"defaultApp\" given" : "Наведен је неисправан тип за постављање „defaultApp”",
    "Invalid setting key" : "Неисправан кључ подешавања",
    "The file was uploaded" : "Фајл је отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Отпремани фајл превазилази смерницу upload_max_filesize у фајлу php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE наведену у ХТМЛ обрасцу",
    "The file was only partially uploaded" : "Фајл је само делимично отпремљен",
    "No file was uploaded" : "Није отпремљен фајл",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Could not write file to disk" : "Не могу да упишем фајл на диск",
    "A PHP extension stopped the file upload" : "ПХП екстензија је зауставила отпремање фајла",
    "No file uploaded" : "Није отпремљен фајл",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Већ користите прилагођену тему. Поставке ове апликације ће прегажене са њом.",
    "Theming" : "Изглед",
    "Appearance and accessibility" : "Изглед и приступачност",
    "PHP Imagick module" : "PHP Imagick модул",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP модул „imagick” није укључен мада је укључена апликација за теме. Да би генерисање favicon сличице функционисало како треба, морате да инсталирате и укључите овај модул.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "PHP модул „imagick” у овој инстанци нема подршку за SVG. Да бисте постигли бољу компатибилност, препоручује се да га инсталирате.",
    "Dark theme with high contrast mode" : "Тамна тема са режимом високог контраста",
    "Enable dark high contrast mode" : "Укључи тамни режим високог контраста",
    "Similar to the high contrast mode, but with dark colours." : "Слично као режим високог контраста, али са тамним бојама.",
    "Dark theme" : "Тамна тема",
    "Enable dark theme" : "укључи тамну тему",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Тамна тема која не замара ваше очи тако што смањује општу сјајност и осветљеност.",
    "System default theme" : "Подразумевана системска тема",
    "Enable the system default" : "Укључи подразумевано за систем",
    "Using the default system appearance." : "Користи се подразумевани изглед система.",
    "Dyslexia font" : "Фонт Дислексија",
    "Enable dyslexia font" : "укључи фонт Дислексија",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "„OpenDyslexic“ је бесплатни фонт дизајниран да умањи честе грешке у читању изазване дислексијом.",
    "High contrast mode" : "Режим високог контраста",
    "Enable high contrast mode" : "укључи режим високог контраста",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Режим високог контраста за лакшу навигацију. Визуелни доживљај биће лошији али ће јасноћа бити боља.",
    "Light theme" : "Светла тема",
    "Enable the default light theme" : "Укључује подразумевану светлу тему",
    "The default light appearance." : "Подразумевани светли изглед.",
    "Legal notice" : "Правно обавештење",
    "Privacy policy" : "Смернице приватности",
    "Adjust the Nextcloud theme" : "Прилагоди Некстклауд тему",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Омогућава да лако измените изглед и угођај вашег Некстклауда. Ово ће бити видљиво свим корисницима.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Уместо позадинске слике, такође можете да подесите и просту једнобојну позадину. Ако користите позадинску слику, измена ове боје ће утицати на боју икона у менију апликације.",
    "Background color" : "Боја позадине",
    "Upload new logo" : "Отпремите нови лого",
    "Logo" : "Лого",
    "Upload new background and login image" : "Отпреми нову слику позадине и пријављивања",
    "Background and login image" : "Позадина и слика пријављивања",
    "Advanced options" : "Напредне опције",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Инсталирајте ImageMagick PHP проширење са подшком за SVG слике да би било могуће аутоматско генерисање favicons према отпремљеном логоу и боји.",
    "Name" : "Назив",
    "Web link" : "Веб веза",
    "a safe home for all your data" : "сигурно место за све ваше податке",
    "Slogan" : "Слоган",
    "Primary color" : "Примарна боја",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Примарна боја се користи за истицање елемената као што су важни дугмићи. Може се донекле изменити у зависности од текуће схеме боја.",
    "Legal notice link" : "Правно обавештење",
    "Privacy policy link" : "Смернице приватности",
    "Header logo" : "Лого заглавља",
    "Upload new header logo" : "Отпремите нови лого заглавља",
    "Favicon" : "Икона веб стране",
    "Upload new favicon" : "Отпремите нову иконицу",
    "User settings" : "Корисничка подешавања",
    "Disable user theming" : "Искључи корисничке теме",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Мада можете да изаберете и прилагодите своју инстанцу, корисници такође могу да промене своју позадину и боје. Ако желите да форсирате своје прилагођавање, укључите ово подешавање.",
    "Appearance and accessibility settings" : "Подешавања изгледа и приступачности",
    "Misc accessibility options" : "Разне опције приступаности",
    "Enable blur background filter (may increase GPU load)" : "Укључи филтер замућења позадине (може да повећа оптерећење GPU)",
    "Customization has been disabled by your administrator" : "Администратор је искључио могућност прилагођавања",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Поставља примарну боју за истицање важних елемената. Боја које се употреби за елементе као што су примарни дугмићи би могла донекле да се промени јер се подешава тако да задовољи захтеве приступачности.",
    "Background and color" : "Позадина и боја",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Позадина може да се постави на слику из подразумеваног скупа, произвољну отпремљену слику или просту боју.",
    "Keyboard shortcuts" : "Пречице на тастатури",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "У неким случајевима пречице тастатуре могу да ремете алатке приступачности. Ако желите да се ваш алат исправно фокусира, овде можете да искључите све пречице на тастатури. Ово ће такође да искључи и све пречице у апликацијама.",
    "Disable all keyboard shortcuts" : "Искључи све пречице на тастатури",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Универзални приступ нам је веома важан. Пратимо веб стандарде и проверавамо да све буде употребљиво и без миша а и са помоћним софтвером попут читача екрана. Циљ нам је да будемо усклађени са документом {guidelines}Смернице приступачности веб садржаја{linkend}  2.1 на АА нивоу а са темом високог контраста и на ААА нивоу.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "У случају да наиђете на било какве проблеме, не оклевајте да их пријавите на {issuetracker}наш пратилац проблема{linkend}. А ако желите да се умешате, слободно се прикључите {designteam}нашем дизајн тиму{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Тренутно изабрана апликација: {app}, позиција {position} од {total}",
    "Move up" : "Помери нагоре",
    "Move down" : "Помери надоле",
    "Custom background" : "Прилагођена позадина",
    "Plain background" : "Проста позадина",
    "Default background" : "Подразумевана позадина",
    "Select a background from your files" : "Изаберите позадину међу вашим фајловима",
    "Select background" : "Изаберите позадину",
    "No background has been selected" : "Није изабрана ниједна позадина",
    "Theme selection is enforced" : "Избор теме је форсиран",
    "Navigation bar settings" : "Подешавања траке за навигацију",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Можете да подесите редослед апликација који ће се користити на траци за навигацију. Прва ставка ће бити подразумевана апликација која се отвара након пријаве или када се кликне на лого.",
    "The default app can not be changed because it was configured by the administrator." : "Подразумевана апликација не може да се промени јер ју је подесио администратор.",
    "The app order was changed, to see it in action you have to reload the page." : "Редослед апликација је променњен, да бисте видели како изгледа, поново учитајте страницу.",
    "Reset default app order" : "Ресетуј подразумевани редослед апликација.",
    "Could not set the app order" : "Није могао да се подеси редослед апликација",
    "Could not reset the app order" : "Није могао да се ресетује редослед апликација",
    "Reset primary color" : "Ресетуј примарну боју",
    "Could not set primary color" : "Није могла да се постави примарна боја",
    "Default app" : "Подразумевана апликација",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Подразумевана апликација је она која се нпр. отвара након пријаве или када се кликне на лого у менију.",
    "Use custom default app" : "Користи произвољну подразумевану апликацију",
    "Global default app" : "Глобална подразумевана апликација",
    "Global default apps" : "Глобалне подразумеване апликације",
    "Default app priority" : "Подразумевани приоритет апликације",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Ако апликација није укључена за корисника, користиће се наредна апликација са нижим приоритетом.",
    "Could not set global default apps" : "Нису могле да се поставе глобалне подразумеване апликације",
    "Select a custom color" : "Изаберите прилагођену боју",
    "Reset to default" : "Врати на подразумевано",
    "Upload" : "Отпреми",
    "Remove background image" : "Уклони позадинску слику",
    "Color" : "Боја",
    "Background" : "Позадина",
    "Set a custom background" : "Постави пролагођену позадину",
    "Change color" : "Промени боју",
    "No background" : "Без позадине"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
